Load cached YList data
ylist_load.RdLoads the cached YList tab-delimited data as a data frame. If the cache does not exist, the public data file is downloaded first.
ylist_load.RdLoads the cached YList tab-delimited data as a data frame. If the cache does not exist, the public data file is downloaded first.