Unofficial Access to YList Japanese Plant Name Data
ylistjp-package.RdFetches and caches the public tab-delimited YList data file and provides helpers for looking up scientific plant names from Japanese names.
ylistjp-package.RdFetches and caches the public tab-delimited YList data file and provides helpers for looking up scientific plant names from Japanese names.